public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Yinghai Lu <yinghai@kernel.org>
To: Ingo Molnar <mingo@elte.hu>, Thomas Gleixner <tglx@linutronix.de>,
	"H. Peter Anvin" <hpa@zytor.com>,
	Andrew Morton <akpm@linux-foundation.org>,
	Jesse Barnes <jbarnes@virtuousgeek.org>,
	Christoph Lameter <cl@linux-foundation.org>
Cc: Linus Torvalds <torvalds@linux-foundation.org>,
	linux-kernel@vger.kernel.org, linux-pci@vger.kernel.org,
	Yinghai Lu <yinghai@kernel.org>
Subject: [PATCH 23/36] x86: add find_fw_memmap_area
Date: Wed, 20 Jan 2010 22:28:10 -0800	[thread overview]
Message-ID: <1264055303-15123-24-git-send-email-yinghai@kernel.org> (raw)
In-Reply-To: <1264055303-15123-1-git-send-email-yinghai@kernel.org>

so could move early_res up

Signed-off-by: Yinghai Lu <yinghai@kernel.org>
---
 arch/x86/include/asm/early_res.h |    1 +
 arch/x86/kernel/e820.c           |    4 ++++
 arch/x86/kernel/early_res.c      |   17 +++++++++++------
 3 files changed, 16 insertions(+), 6 deletions(-)

diff --git a/arch/x86/include/asm/early_res.h b/arch/x86/include/asm/early_res.h
index 5a4d2eb..9758f3d 100644
--- a/arch/x86/include/asm/early_res.h
+++ b/arch/x86/include/asm/early_res.h
@@ -12,6 +12,7 @@ u64 find_early_area(u64 ei_start, u64 ei_last, u64 start, u64 end,
 			 u64 size, u64 align);
 u64 find_early_area_size(u64 ei_start, u64 ei_last, u64 start,
 			 u64 *sizep, u64 align);
+u64 find_fw_memmap_area(u64 start, u64 end, u64 size, u64 align);
 #include <linux/range.h>
 int get_free_all_memory_range(struct range **rangep, int nodeid);
 
diff --git a/arch/x86/kernel/e820.c b/arch/x86/kernel/e820.c
index acd7be6..5c80050 100644
--- a/arch/x86/kernel/e820.c
+++ b/arch/x86/kernel/e820.c
@@ -742,6 +742,10 @@ u64 __init find_e820_area(u64 start, u64 end, u64 size, u64 align)
 	return -1ULL;
 }
 
+u64 __init find_fw_memmap_area(u64 start, u64 end, u64 size, u64 align)
+{
+	return find_e820_area(start, end, size, align);
+}
 /*
  * Find next free range after *start
  */
diff --git a/arch/x86/kernel/early_res.c b/arch/x86/kernel/early_res.c
index 38a0c61..e209fc4 100644
--- a/arch/x86/kernel/early_res.c
+++ b/arch/x86/kernel/early_res.c
@@ -7,16 +7,14 @@
 #include <linux/bootmem.h>
 #include <linux/mm.h>
 
-#include <asm/e820.h>
 #include <asm/early_res.h>
-#include <asm/proto.h>
 
 /*
  * Early reserved memory areas.
  */
 /*
  * need to make sure this one is bigger enough before
  * find_e820_area could be used
  */
 #define MAX_EARLY_RES_X 32
 
@@ -180,6 +178,13 @@ void __init reserve_early_overlap_ok(u64 start, u64 end, char *name)
 	__reserve_early(start, end, name, 1);
 }
 
+u64 __init __weak find_fw_memmap_area(u64 start, u64 end, u64 size, u64 align)
+{
+	panic("should have find_fw_memmap_area defined with arch");
+
+	return -1ULL;
+}
+
 static void __init __check_and_double_early_res(u64 ex_start, u64 ex_end)
 {
 	u64 start, end, size, mem;
@@ -198,13 +203,13 @@ static void __init __check_and_double_early_res(u64 ex_start, u64 ex_end)
 		start = early_res[0].end;
 	end = ex_start;
 	if (start + size < end)
-		mem = find_e820_area(start, end, size,
+		mem = find_fw_memmap_area(start, end, size,
 					 sizeof(struct early_res));
 	if (mem == -1ULL) {
 		start = ex_end;
 		end = max_pfn_mapped << PAGE_SHIFT;
 		if (start + size < end)
-			mem = find_e820_area(start, end, size,
+			mem = find_fw_memmap_area(start, end, size,
 						 sizeof(struct early_res));
 	}
 	if (mem == -1ULL)
@@ -343,7 +348,7 @@ int __init get_free_all_memory_range(struct range **rangep, int nodeid)
 		start = MAX_DMA32_PFN << PAGE_SHIFT;
 #endif
 	end = max_pfn_mapped << PAGE_SHIFT;
-	mem = find_e820_area(start, end, size, sizeof(struct range));
+	mem = find_fw_memmap_area(start, end, size, sizeof(struct range));
 	if (mem == -1ULL)
 		panic("can not find more space for range free");
 
@@ -7,16 +7,14 @@
 /*
  * need to make sure this one is bigger enough before
- * find_e820_area could be used
+ * find_fw_memmap_area could be used
  */
 #define MAX_EARLY_RES_X 32
-- 
1.6.4.2


  parent reply	other threads:[~2010-01-21  6:29 UTC|newest]

Thread overview: 46+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2010-01-21  6:27 [PATCH -v4 0/36] x86: not use bootmem for x86 Yinghai Lu
2010-01-21  6:27 ` [PATCH 01/36] x86: move range related operation to one file Yinghai Lu
2010-01-21  6:27 ` [PATCH 02/36] x86: check range in update range Yinghai Lu
2010-01-21 20:43   ` Christoph Lameter
2010-01-21 21:02     ` Yinghai Lu
2010-01-21 21:07       ` Christoph Lameter
2010-01-21  6:27 ` [PATCH 03/36] x86/pci: use u64 instead of size_t in amd_bus.c Yinghai Lu
2010-01-21  6:27 ` [PATCH 04/36] x86/pci: add cap_resource Yinghai Lu
2010-01-21 15:49   ` Linus Torvalds
2010-01-21 20:01     ` Yinghai Lu
2010-01-21  6:27 ` [PATCH 05/36] x86/pci: enable pci root res read out for 32bit too Yinghai Lu
2010-01-21 15:54   ` Linus Torvalds
2010-01-21 20:12     ` Yinghai Lu
2010-01-21  6:27 ` [PATCH 06/36] x86: call early_res_to_bootmem one time Yinghai Lu
2010-01-21  6:27 ` [PATCH 07/36] x86: introduce max_early_res and early_res_count Yinghai Lu
2010-01-21  6:27 ` [PATCH 08/36] x86: dynamic increase early_res array size Yinghai Lu
2010-01-21  6:27 ` [PATCH 09/36] x86: print bootmem free before pci_iommu_alloc and free_all_bootmem -v2 Yinghai Lu
2010-01-21  6:27 ` [PATCH 10/36] x86: make early_node_mem get mem > 4g if possible Yinghai Lu
2010-01-21  6:27 ` [PATCH 11/36] x86: only call dma32_reserve_bootmem 64bit !CONFIG_NUMA Yinghai Lu
2010-01-21  6:27 ` [PATCH 12/36] x86: make 64 bit use early_res instead of bootmem before slab Yinghai Lu
2010-01-21  6:28 ` [PATCH 13/36] sparsemem: put usemap for one node together Yinghai Lu
2010-01-21  6:28 ` [PATCH 14/36] sparsemem: put mem map " Yinghai Lu
2010-01-21  6:28 ` [PATCH 15/36] x86: change range end to start+size Yinghai Lu
2010-01-21  6:28 ` [PATCH 16/36] x86: move bios page reserve early to head32/64.c Yinghai Lu
2010-01-21  6:28 ` [PATCH 17/36] x86: seperate early_res related code from e820.c Yinghai Lu
2010-01-21  6:28 ` [PATCH 18/36] x86: add find_early_area_size Yinghai Lu
2010-01-21  6:28 ` [PATCH 19/36] x86: move back find_e820_area to e820.c Yinghai Lu
2010-01-21  6:28 ` [PATCH 20/36] early_res: enhance check_and_double_early_res Yinghai Lu
2010-01-21  6:28 ` [PATCH 21/36] x86: make 32bit support NO_BOOTMEM Yinghai Lu
2010-01-21  6:28 ` [PATCH 22/36] move round_up/down to kernel.h Yinghai Lu
2010-01-21 20:48   ` Christoph Lameter
2010-01-21 23:14     ` Andi Kleen
2010-01-21  6:28 ` Yinghai Lu [this message]
2010-01-21  6:28 ` [PATCH 24/36] core: move early_res Yinghai Lu
2010-01-21  6:28 ` [PATCH 25/36] x86: print out for RAM buffer Yinghai Lu
2010-01-21  6:28 ` [PATCH 26/36] x86: remove bios data range from e820 Yinghai Lu
2010-01-21  6:28 ` [PATCH 27/36] x86/pci: add mmconf range into e820 for when it is from MSR with amd faml0h Yinghai Lu
2010-01-21  6:28 ` [PATCH 28/36] irq: remove not need bootmem code Yinghai Lu
2010-01-21  6:28 ` [PATCH 29/36] radix: move radix init early Yinghai Lu
2010-01-21  6:28 ` [PATCH 30/36] sparseirq: change irq_desc_ptrs to static Yinghai Lu
2010-01-21  6:28 ` [PATCH 31/36] sparseirq: use radix_tree instead of ptrs array Yinghai Lu
2010-01-21  6:28 ` [PATCH 32/36] x86: remove arch_probe_nr_irqs Yinghai Lu
2010-01-21  6:28 ` [PATCH 33/36] use nr_cpus= to set nr_cpu_ids early Yinghai Lu
2010-01-21  6:28 ` [PATCH 34/36] x86: according to nr_cpu_ids to decide if need to leave logical flat Yinghai Lu
2010-01-21  6:28 ` [PATCH 35/36] x86: make 32bit apic flat to physflat switch like 64bit Yinghai Lu
2010-01-21  6:28 ` [PATCH 36/36] x86: use num_processors for possible cpus Yinghai Lu

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1264055303-15123-24-git-send-email-yinghai@kernel.org \
    --to=yinghai@kernel.org \
    --cc=akpm@linux-foundation.org \
    --cc=cl@linux-foundation.org \
    --cc=hpa@zytor.com \
    --cc=jbarnes@virtuousgeek.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-pci@vger.kernel.org \
    --cc=mingo@elte.hu \
    --cc=tglx@linutronix.de \
    --cc=torvalds@linux-foundation.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox